PyXMake Developer Guide: PyXMake.Tools.Utility.GetDataFromPickle Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Member Functions | Static Public Member Functions | Public Attributes | List of all members
PyXMake.Tools.Utility.GetDataFromPickle Class Reference

Class to create 2to3 compatible pickling dictionary. More...

Inheritance diagram for PyXMake.Tools.Utility.GetDataFromPickle:

## Public Member Functions
| __init__ (self, FileName)

## Static Public Member Functions
| getDictfromFile (FileName)

## Public Attributes
| Data = GetDataFromPickle.getDictfromFile(FileName)
| Dictionary for further processing.

## Detailed Description

Class to create 2to3 compatible pickling dictionary.

    Class to convert an arbitrary pickle file (2.x & 3.x) into a readable
    dictionary.

Inherited from built-in object.

## Constructor & Destructor Documentation

## ◆ __init__()

PyXMake.Tools.Utility.GetDataFromPickle.__init__ | ( |  | self,
|  |  | FileName )

    Get a dictionary from a *.cpd file.

    @param: self, FileName
    @type: self: object
    @type: FileName: string

Definition at line 323 of file Utility.py.

## Member Function Documentation

## ◆ getDictfromFile()

PyXMake.Tools.Utility.GetDataFromPickle.getDictfromFile | ( |  | FileName | ) |
| static

    Open a *.cpd file and extract the dictionary stored within.

    @param: FileName
    @type: FileName: string

Definition at line 336 of file Utility.py.

## Member Data Documentation

## ◆ Data

PyXMake.Tools.Utility.GetDataFromPickle.Data = GetDataFromPickle.getDictfromFile(FileName)

Dictionary for further processing.

Definition at line 332 of file Utility.py.

The documentation for this class was generated from the following file:

- src/PyXMake/Tools/Utility.py